import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '../views/layout/Layout'

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    roles: ['admin','editor']     will control the page roles (you can set multiple roles)
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
    noCache: true                if true ,the page will no be cached(default is false)
  }
**/

// 所有权限通用路由表
// 如首页和登录页和一些不用权限的公用页面

export const constantRouterMap = [
  { path: '/login', component: () => import('@/views/login/index'), hidden: true },
  { path: '/findPwd', component: () => import('@/views/findPwd/index'), hidden: true },
  { path: '/404', component: () => import('@/views/404'), hidden: true },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    hidden: true,
    children: [{
      path: 'dashboard',
      component: () => import('@/views/dashboard'),
      name: 'dashboard',
      meta: { title: '主页' }
    }]
  },
  {
    path: '',
    component: Layout,
    name: 'content',
    redirect: 'noredirect',
    meta: { title: '内容发布' },
    children: [
      {
        path: 'pubList',
        component: () => import('@/views/contentPub/pubList'),
        name: 'pubList',
        meta: { title: '内容发布列表' }
      },
      {
        path: 'draftList',
        component: () => import('@/views/contentPub/draftList'),
        name: 'draftList',
        meta: { title: '内容草稿箱列表' }
      },
      {
        path: 'recycleBin',
        component: () => import('@/views/contentPub/recycleBin'),
        name: 'recycleBin',
        meta: { title: '内容回收站列表' }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    name: 'demand',
    redirect: 'noredirect',
    meta: { title: '需求中心' },
    children: [
      {
        path: 'publishedList',
        component: () => import('@/views/demandCen/publishedList'),
        name: 'publishedList',
        meta: { title: '发布中需求' }
      },
      {
        path: 'expiredList',
        component: () => import('@/views/demandCen/expiredList'),
        name: 'expiredList',
        meta: { title: '已过期需求' }
      },
      {
        path: 'completedList',
        component: () => import('@/views/demandCen/completedList'),
        name: 'completedList',
        meta: { title: '已完成需求' }
      },
      {
        path: 'closedList',
        component: () => import('@/views/demandCen/closedList'),
        name: 'closedList',
        meta: { title: '已关闭需求' }
      }
    ]
  }
]

// 实例化vue的时候只挂载constantRouter

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})

// 异步挂载的路由
// 动态需要根据权限加载的路由表

export const asyncRouterMap = [
  
  { path: '*', redirect: '/404', hidden: true }
]
